@@ -4,4 +4,4 @@
 -- Variant for the 'ST' monad.
 --
 -- The 'Vault' type in this module is strict in the keys but lazy in the values.
-#include "ST.hs"
+#include "ST.h"
